pub struct AccountingByteMeasurement {
pub state: i32,
pub bytes: u64,
}Fields
state: i32bytes: u64Implementations
Sourceimpl AccountingByteMeasurement
impl AccountingByteMeasurement
Sourcepub fn state(&self) -> AccountingMeasurementState
pub fn state(&self) -> AccountingMeasurementState
Returns the enum value of state, or the default if the field is set to an invalid enum value.
Sourcepub fn set_state(&mut self, value: AccountingMeasurementState)
pub fn set_state(&mut self, value: AccountingMeasurementState)
Sets state to the provided enum value.