pub struct AccountingCountMeasurement {
pub state: i32,
pub count: u64,
}Fields
state: i32count: u64Implementations
Sourceimpl AccountingCountMeasurement
impl AccountingCountMeasurement
Sourcepub fn state(&self) -> AccountingMeasurementState
pub fn state(&self) -> AccountingMeasurementState
Returns the enum value of state, or the default if the field is set to an invalid enum value.
Sourcepub fn set_state(&mut self, value: AccountingMeasurementState)
pub fn set_state(&mut self, value: AccountingMeasurementState)
Sets state to the provided enum value.