pub struct CloneObjectRequest {
pub source: Option<ObjectAddress>,
pub source_version: u64,
pub destination: Option<ObjectAddress>,
pub command_id: String,
pub durability: i32,
pub operation: Option<Operation>,
}Fields
source: Option<ObjectAddress>source_version: u64destination: Option<ObjectAddress>command_id: Stringdurability: i32operation: Option<Operation>Implementations
Sourceimpl CloneObjectRequest
impl CloneObjectRequest
Sourcepub fn durability(&self) -> Durability
pub fn durability(&self) -> Durability
Returns the enum value of durability, or the default if the field is set to an invalid enum value.
Sourcepub fn set_durability(&mut self, value: Durability)
pub fn set_durability(&mut self, value: Durability)
Sets durability to the provided enum value.