pub struct ClusterCapabilities {
pub active_protocol_version: u32,
pub active_storage_format: u32,
pub target_protocol_version: u32,
pub target_storage_format: u32,
pub active_placement_term: u64,
pub active_placement_index: u64,
pub ready_for_target_activation: bool,
pub blocking_active_node_ids: Vec<u64>,
pub activation_quiescent: bool,
}Fields
active_protocol_version: u32active_storage_format: u32target_protocol_version: u32target_storage_format: u32active_placement_term: u64active_placement_index: u64ready_for_target_activation: boolblocking_active_node_ids: Vec<u64>activation_quiescent: boolTrait Implementations
Sourceimpl Clone for ClusterCapabilities
impl Clone for ClusterCapabilities
Sourcefn clone(&self) -> ClusterCapabilities
fn clone(&self) -> ClusterCapabilities
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ClusterCapabilities
impl Debug for ClusterCapabilities
Sourceimpl Default for ClusterCapabilities
impl Default for ClusterCapabilities
impl Eq for ClusterCapabilities
Sourceimpl Hash for ClusterCapabilities
impl Hash for ClusterCapabilities
Sourceimpl Message for ClusterCapabilities
impl Message for ClusterCapabilities
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for ClusterCapabilities
impl PartialEq for ClusterCapabilities
impl StructuralPartialEq for ClusterCapabilities