pub struct ClusterLogicalFileCounts {
pub visible_file_count: Option<AccountingCountMeasurement>,
pub tenants: Vec<TenantLogicalFileCount>,
pub active_source_node_count: u32,
pub reported_source_node_count: u32,
pub sources: Vec<NodeLogicalFileCountSource>,
}Fields
visible_file_count: Option<AccountingCountMeasurement>PRESENT only when every ACTIVE source owner reported from its current placement-fenced snapshot; otherwise UNAVAILABLE and zero.
tenants: Vec<TenantLogicalFileCount>Exact non-zero tenant counts, ordered by stable tenant ID. A tenant absent from a PRESENT snapshot has zero visible files.
active_source_node_count: u32reported_source_node_count: u32sources: Vec<NodeLogicalFileCountSource>Trait Implementations
Sourceimpl Clone for ClusterLogicalFileCounts
impl Clone for ClusterLogicalFileCounts
Sourcefn clone(&self) -> ClusterLogicalFileCounts
fn clone(&self) -> ClusterLogicalFileCounts
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ClusterLogicalFileCounts
impl Debug for ClusterLogicalFileCounts
Sourceimpl Default for ClusterLogicalFileCounts
impl Default for ClusterLogicalFileCounts
Sourceimpl Message for ClusterLogicalFileCounts
impl Message for ClusterLogicalFileCounts
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for ClusterLogicalFileCounts
impl PartialEq for ClusterLogicalFileCounts
impl StructuralPartialEq for ClusterLogicalFileCounts