pub struct ClusterPhysicalStorage {
pub live_payload_blob_bytes: Option<AccountingByteMeasurement>,
pub garbage_payload_blob_bytes: Option<AccountingByteMeasurement>,
pub payload_sst_bytes: Option<AccountingByteMeasurement>,
pub metadata_index_sst_bytes: Option<AccountingByteMeasurement>,
pub wal_bytes: Option<AccountingByteMeasurement>,
pub active_node_count: u32,
pub reported_node_count: u32,
pub reported_storage_replica_count: u32,
pub nodes: Vec<NodePhysicalStorage>,
}Fields
live_payload_blob_bytes: Option<AccountingByteMeasurement>A present total is the sum of every ACTIVE node’s local observation and therefore includes replica copies. It is not a unique-content total.
garbage_payload_blob_bytes: Option<AccountingByteMeasurement>payload_sst_bytes: Option<AccountingByteMeasurement>metadata_index_sst_bytes: Option<AccountingByteMeasurement>wal_bytes: Option<AccountingByteMeasurement>active_node_count: u32reported_node_count: u32reported_storage_replica_count: u32Number of replica-inclusive node stores represented by the totals.
nodes: Vec<NodePhysicalStorage>Trait Implementations
Sourceimpl Clone for ClusterPhysicalStorage
impl Clone for ClusterPhysicalStorage
Sourcefn clone(&self) -> ClusterPhysicalStorage
fn clone(&self) -> ClusterPhysicalStorage
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ClusterPhysicalStorage
impl Debug for ClusterPhysicalStorage
Sourceimpl Default for ClusterPhysicalStorage
impl Default for ClusterPhysicalStorage
Sourceimpl Message for ClusterPhysicalStorage
impl Message for ClusterPhysicalStorage
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for ClusterPhysicalStorage
impl PartialEq for ClusterPhysicalStorage
impl StructuralPartialEq for ClusterPhysicalStorage