pub struct IndexAggregateRequest {
pub field: String,
pub operation: i32,
}Fields
field: Stringoperation: i32Implementations
Sourceimpl IndexAggregateRequest
impl IndexAggregateRequest
Sourcepub fn operation(&self) -> IndexAggregateOperation
pub fn operation(&self) -> IndexAggregateOperation
Returns the enum value of operation, or the default if the field is set to an invalid enum value.
Sourcepub fn set_operation(&mut self, value: IndexAggregateOperation)
pub fn set_operation(&mut self, value: IndexAggregateOperation)
Sets operation to the provided enum value.