pub struct LinkObjectRequest {
pub link: Option<ObjectAddress>,
pub target: Option<ObjectAddress>,
pub command_id: String,
pub durability: i32,
}Fields
link: Option<ObjectAddress>target: Option<ObjectAddress>command_id: Stringdurability: i32Implementations
Sourceimpl LinkObjectRequest
impl LinkObjectRequest
Sourcepub fn durability(&self) -> Durability
pub fn durability(&self) -> Durability
Returns the enum value of durability, or the default if the field is set to an invalid enum value.
Sourcepub fn set_durability(&mut self, value: Durability)
pub fn set_durability(&mut self, value: Durability)
Sets durability to the provided enum value.