pub struct NodePhysicalStorage {
pub node_id: u64,
pub refreshed_at: Option<Timestamp>,
pub live_payload_blob_bytes: Option<AccountingByteMeasurement>,
pub garbage_payload_blob_bytes: Option<AccountingByteMeasurement>,
pub payload_sst_bytes: Option<AccountingByteMeasurement>,
pub metadata_index_sst_bytes: Option<AccountingByteMeasurement>,
pub wal_bytes: Option<AccountingByteMeasurement>,
}Fields
node_id: u64refreshed_at: Option<Timestamp>live_payload_blob_bytes: Option<AccountingByteMeasurement>Payload bytes in live BlobDB files excluding the garbage bytes reported separately below, so the physical categories can be summed.
garbage_payload_blob_bytes: Option<AccountingByteMeasurement>payload_sst_bytes: Option<AccountingByteMeasurement>metadata_index_sst_bytes: Option<AccountingByteMeasurement>wal_bytes: Option<AccountingByteMeasurement>Trait Implementations
Sourceimpl Clone for NodePhysicalStorage
impl Clone for NodePhysicalStorage
Sourcefn clone(&self) -> NodePhysicalStorage
fn clone(&self) -> NodePhysicalStorage
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for NodePhysicalStorage
Sourceimpl Debug for NodePhysicalStorage
impl Debug for NodePhysicalStorage
Sourceimpl Default for NodePhysicalStorage
impl Default for NodePhysicalStorage
impl Eq for NodePhysicalStorage
Sourceimpl Hash for NodePhysicalStorage
impl Hash for NodePhysicalStorage
Sourceimpl Message for NodePhysicalStorage
impl Message for NodePhysicalStorage
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for NodePhysicalStorage
impl PartialEq for NodePhysicalStorage
impl StructuralPartialEq for NodePhysicalStorage