pub struct TextIndexField {
pub analyzer: i32,
}Fields
analyzer: i32Implementations
Sourceimpl TextIndexField
impl TextIndexField
Sourcepub fn analyzer(&self) -> TextAnalyzer
pub fn analyzer(&self) -> TextAnalyzer
Returns the enum value of analyzer, or the default if the field is set to an invalid enum value.
Sourcepub fn set_analyzer(&mut self, value: TextAnalyzer)
pub fn set_analyzer(&mut self, value: TextAnalyzer)
Sets analyzer to the provided enum value.